==> osmosis_protobuf-0.1.0.tar.gz: osmosis_protobuf-0.1.0/src/osmosis_protobuf/tendermint/p2p/pex_pb2.py <==
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ...tendermint.p2p import types_pb2 as tendermint_dot_p2p_dot_types__pb2
from ...gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18tendermint/p2p/pex.proto\x12\x0etendermint.p2p\x1a\x1atendermint/p2p/types.proto\x1a\x14gogoproto/gogo.proto"\x0c\n\nPexRequest";\n\x08PexAddrs\x12/\n\x05addrs\x18\x01 \x03(\x0b2\x1a.tendermint.p2p.NetAddressB\x04\xc8\xde\x1f\x00"r\n\x07Message\x121\n\x0bpex_request\x18\x01 \x01(\x0b2\x1a.tendermint.p2p.PexRequestH\x00\x12-\n\tpex_addrs\x18\x02 \x01(\x0b2\x18.tendermint.p2p.PexAddrsH\x00B\x05\n\x03sumB7Z5github.com/tendermint/tendermint/proto/tendermint/p2pb\x06proto3')
_PEXREQUEST = DESCRIPTOR.message_types_by_name['PexRequest']
_PEXADDRS = DESCRIPTOR.message_types_by_name['PexAddrs']
_MESSAGE = DESCRIPTOR.message_types_by_name['Message']
PexRequest = _reflection.GeneratedProtocolMessageType('PexRequest', (_message.Message,), {'DESCRIPTOR': _PEXREQUEST, '__module__': 'tendermint.p2p.pex_pb2'})
_sym_db.RegisterMessage(PexRequest)
PexAddrs = _reflection.GeneratedProtocolMessageType('PexAddrs', (_message.Message,), {'DESCRIPTOR': _PEXADDRS, '__module__': 'tendermint.p2p.pex_pb2'})
_sym_db.RegisterMessage(PexAddrs)
Message = _reflection.GeneratedProtocolMessageType('Message', (_message.Message,), {'DESCRIPTOR': _MESSAGE, '__module__': 'tendermint.p2p.pex_pb2'})
_sym_db.RegisterMessage(Message)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z5github.com/tendermint/tendermint/proto/tendermint/p2p'
    _PEXADDRS.fields_by_name['addrs']._options = None
    _PEXADDRS.fields_by_name['addrs']._serialized_options = b'\xc8\xde\x1f\x00'
    _PEXREQUEST._serialized_start = 94
    _PEXREQUEST._serialized_end = 106
    _PEXADDRS._serialized_start = 108
    _PEXADDRS._serialized_end = 167
    _MESSAGE._serialized_start = 169
    _MESSAGE._serialized_end = 283

==> osmosis_protobuf-0.1.2.tar.gz: osmosis_protobuf-0.1.2/src/osmosis_protobuf/tendermint/p2p/pex_pb2.py <==
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ...tendermint.p2p import types_pb2 as tendermint_dot_p2p_dot_types__pb2
from ...gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18tendermint/p2p/pex.proto\x12\x0etendermint.p2p\x1a\x1atendermint/p2p/types.proto\x1a\x14gogoproto/gogo.proto"\x0c\n\nPexRequest";\n\x08PexAddrs\x12/\n\x05addrs\x18\x01 \x03(\x0b2\x1a.tendermint.p2p.NetAddressB\x04\xc8\xde\x1f\x00"r\n\x07Message\x121\n\x0bpex_request\x18\x01 \x01(\x0b2\x1a.tendermint.p2p.PexRequestH\x00\x12-\n\tpex_addrs\x18\x02 \x01(\x0b2\x18.tendermint.p2p.PexAddrsH\x00B\x05\n\x03sumB7Z5github.com/tendermint/tendermint/proto/tendermint/p2pb\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tendermint.p2p.pex_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z5github.com/tendermint/tendermint/proto/tendermint/p2p'
    _PEXADDRS.fields_by_name['addrs']._options = None
    _PEXADDRS.fields_by_name['addrs']._serialized_options = b'\xc8\xde\x1f\x00'
    _PEXREQUEST._serialized_start = 94
    _PEXREQUEST._serialized_end = 106
    _PEXADDRS._serialized_start = 108
    _PEXADDRS._serialized_end = 167
    _MESSAGE._serialized_start = 169
    _MESSAGE._serialized_end = 283
